==> jc-1.4.0.tar.gz: java/text/ParsePosition.h <==
// public class java.text.ParsePosition

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 40ba3f7bd03c5728 java_text_ParsePosition

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_ParsePosition_H_
#define _JC_java_text_ParsePosition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_ParsePosition$sub_refs	_jc_java_text_ParsePosition$sub_refs;
typedef struct _jc_java_text_ParsePosition$sub_nonrefs	_jc_java_text_ParsePosition$sub_nonrefs;
typedef struct _jc_java_text_ParsePosition$refs	_jc_java_text_ParsePosition$refs;
typedef struct _jc_java_text_ParsePosition$nonrefs	_jc_java_text_ParsePosition$nonrefs;
typedef struct _jc_java_text_ParsePosition$object	_jc_java_text_ParsePosition$object;

typedef const struct _jc_java_text_ParsePosition$vmethods	_jc_java_text_ParsePosition$vmethods;
typedef const struct _jc_java_text_ParsePosition$vtable	_jc_java_text_ParsePosition$vtable;
typedef const struct _jc_java_text_ParsePosition$vtype	_jc_java_text_ParsePosition$vtype;

// Constructors
extern void _jc_java_text_ParsePosition$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint);

// Virtual methods
extern jboolean _jc_java_text_ParsePosition$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_text_ParsePosition$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_text_ParsePosition$method$getErrorIndex$cf29c67da3d8b446(_jc_env *, struct _jc_java_text_ParsePosition$object *);
extern jint _jc_java_text_ParsePosition$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_text_ParsePosition$object *);
extern void _jc_java_text_ParsePosition$method$setErrorIndex$4a9c3468aa509917(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint);
extern void _jc_java_text_ParsePosition$method$setIndex$a44eec73e9c18719(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint);
extern struct _jc_java_lang_String$object *_jc_java_text_ParsePosition$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_ParsePosition$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_ParsePosition$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_text_ParsePosition$method_info$getErrorIndex$cf29c67da3d8b446;
extern _jc_method _jc_java_text_ParsePosition$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_text_ParsePosition$method_info$setErrorIndex$4a9c3468aa509917;
extern _jc_method _jc_java_text_ParsePosition$method_info$setIndex$a44eec73e9c18719;
extern _jc_method _jc_java_text_ParsePosition$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_text_ParsePosition$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_text_ParsePosition$object *, struct _jc_java_lang_Object$object *);
	jint	(*getErrorIndex$cf29c67da3d8b446)(_jc_env *, struct _jc_java_text_ParsePosition$object *);
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_text_ParsePosition$object *);
	void	(*setErrorIndex$4a9c3468aa509917)(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint);
	void	(*setIndex$a44eec73e9c18719)(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_ParsePosition$object *);
};

// Vtable
struct _jc_java_text_ParsePosition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_ParsePosition$vmethods	java_text_ParsePosition;
};

// Vtype
struct _jc_java_text_ParsePosition$vtype {
	_jc_type			type;
	_jc_java_text_ParsePosition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_ParsePosition$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_ParsePosition$refs {
    _jc_java_text_ParsePosition$sub_refs	java_text_ParsePosition;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_ParsePosition$sub_nonrefs {
	jint	index;
	jint	error__5findex;
};

// Non-reference instance fields (object)
struct _jc_java_text_ParsePosition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_ParsePosition$sub_nonrefs	java_text_ParsePosition;
};

// Object instance structure
struct _jc_java_text_ParsePosition$object {
	_jc_java_text_ParsePosition$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_ParsePosition$vtype	*vtype;
	_jc_java_text_ParsePosition$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_ParsePosition$vtype _jc_java_text_ParsePosition$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_ParsePosition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_ParsePosition$class_object;

#endif	/* _JC_java_text_ParsePosition_H_ */

==> jc-1.4.6.tar.gz: java/text/ParsePosition.h <==
// public class java.text.ParsePosition

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 40ba3f7bd03c5728 java_text_ParsePosition

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_ParsePosition_H_
#define _JC_java_text_ParsePosition_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_ParsePosition$sub_refs	_jc_java_text_ParsePosition$sub_refs;
typedef struct _jc_java_text_ParsePosition$sub_nonrefs	_jc_java_text_ParsePosition$sub_nonrefs;
typedef struct _jc_java_text_ParsePosition$refs	_jc_java_text_ParsePosition$refs;
typedef struct _jc_java_text_ParsePosition$nonrefs	_jc_java_text_ParsePosition$nonrefs;
typedef struct _jc_java_text_ParsePosition$object	_jc_java_text_ParsePosition$object;

typedef const struct _jc_java_text_ParsePosition$vmethods	_jc_java_text_ParsePosition$vmethods;
typedef const struct _jc_java_text_ParsePosition$vtable	_jc_java_text_ParsePosition$vtable;
typedef const struct _jc_java_text_ParsePosition$vtype	_jc_java_text_ParsePosition$vtype;

// Constructors
extern void _jc_java_text_ParsePosition$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_text_ParsePosition$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_text_ParsePosition$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_ParsePosition$method$getErrorIndex$cf29c67da3d8b446(_jc_env *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
extern jint _jc_java_text_ParsePosition$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
extern void _jc_java_text_ParsePosition$method$setErrorIndex$4a9c3468aa509917(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_text_ParsePosition$method$setIndex$a44eec73e9c18719(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_text_ParsePosition$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_ParsePosition$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_text_ParsePosition$method_info$getErrorIndex$cf29c67da3d8b446;
extern _jc_method _jc_java_text_ParsePosition$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_text_ParsePosition$method_info$setErrorIndex$4a9c3468aa509917;
extern _jc_method _jc_java_text_ParsePosition$method_info$setIndex$a44eec73e9c18719;
extern _jc_method _jc_java_text_ParsePosition$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_text_ParsePosition$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_text_ParsePosition$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*getErrorIndex$cf29c67da3d8b446)(_jc_env *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
	void	(*setErrorIndex$4a9c3468aa509917)(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint) _JC_JCNI_ATTR;
	void	(*setIndex$a44eec73e9c18719)(_jc_env *, struct _jc_java_text_ParsePosition$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_text_ParsePosition$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_ParsePosition$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_ParsePosition$vmethods	java_text_ParsePosition;
};

// Vtype
struct _jc_java_text_ParsePosition$vtype {
	_jc_type			type;
	_jc_java_text_ParsePosition$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_ParsePosition$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_ParsePosition$refs {
    _jc_java_text_ParsePosition$sub_refs	java_text_ParsePosition;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_ParsePosition$sub_nonrefs {
	jint	index;
	jint	error__5findex;
};

// Non-reference instance fields (object)
struct _jc_java_text_ParsePosition$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_ParsePosition$sub_nonrefs	java_text_ParsePosition;
};

// Object instance structure
struct _jc_java_text_ParsePosition$object {
	_jc_java_text_ParsePosition$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_ParsePosition$vtype	*vtype;
	_jc_java_text_ParsePosition$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_ParsePosition$vtype _jc_java_text_ParsePosition$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_ParsePosition, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_ParsePosition$class_object;

#endif	/* _JC_java_text_ParsePosition_H_ */
